==> eiffelstudio-16.05.tar: F_code/C2/po92.c <==
/*
 * Code for class PO_FILE_ENTRY_SINGULAR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po92.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_ENTRY_SINGULAR}.make */
void F129_1527 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	F127_1494(Current, arg1);
	{
		static EIF_TYPE_INDEX typarr0[] = {671,896,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F672_4137(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_ENTRY_SINGULAR}.to_string */
EIF_REFERENCE F129_1530 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	Result = F127_1507(Current);
	tr1 = RTMS_EX_H("msgstr",6,1950805618);
	tr1 = F888_6651(tr1);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	tr1 = F127_1511(Current, tr1, tr2);
	F897_6982(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {PO_FILE_ENTRY_SINGULAR}.msgstr_lines */
EIF_REFERENCE F129_1531 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


void EIF_Minit92 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C2/po92.c <==
/*
 * Code for class PO_FILE_ENTRY_SINGULAR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po92.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_ENTRY_SINGULAR}.make */
void F129_1557 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,arg2);
	RTLIU(4);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,672,0xFF01,947,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F673_4254(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	F127_1525(Current, arg1, arg2);
	RTLE;
}

/* {PO_FILE_ENTRY_SINGULAR}.to_string */
EIF_REFERENCE F129_1560 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	Result = F127_1537(Current);
	tr1 = RTMS_EX_H("msgstr",6,1950805618);
	tr1 = F939_6880(tr1);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	tr1 = F127_1541(Current, tr1, tr2);
	F948_7230(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {PO_FILE_ENTRY_SINGULAR}.msgstr_lines */
EIF_REFERENCE F129_1561 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


void EIF_Minit92 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
